@@ -13,7 +13,7 @@ use Exporter 'import';
 use Scalar::Util ();
 use Encode ();
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 our @EXPORT_OK = qw(decode_json encode_json j);
 
 # Constructor and error inlined from Mojo::Base
@@ -284,12 +284,10 @@ sub _encode_value {
   return 'null' unless defined $value;
 
   # Number
-  if(B::svref_2object(\$value)->FLAGS & (B::SVp_IOK | B::SVp_NOK)) {
-    no warnings 'numeric';
-    my $num = $value;
-    $num += 0;
-    return $num if $num eq $value && $num * 0 == 0;
-  }
+  return $value
+    if B::svref_2object(\$value)->FLAGS & (B::SVp_IOK | B::SVp_NOK)
+    && 0 + $value eq $value
+    && $value * 0 == 0;
 
   # String
   return _encode_string($value);
